# TODO
# - lxdbr0 interface setup for systemd
# - Consider use of lxd group for lxd

Summary:	Fast, dense and secure container management
Name:		lxd
Version:	2.6.2
Release:	1	
License:	Apache v2.0
Group:		Applications/System
Source0:	https://linuxcontainers.org/downloads/lxd/%{name}-%{version}.tar.gz
# Source0-md5:	59a4f949c7cc6bb3846998e9d4e9adaa
Source1:	%{name}.service
Source2:	%{name}.init
Source3:	%{name}br.init
Source4:	%{name}.sysconfig
Source5:	%{name}.sh
URL:		http://linuxcontainers.org/
%ifarch %{x8664} arm aarch64 ppc64
BuildRequires:	criu-devel >= 1.7
%endif
BuildRequires:	golang >= 1.5
BuildRequires:	lxc-devel >= 1.1
BuildRequires:	pkgconfig
BuildRequires:	rpmbuild(macros) >= 1.228
Requires(post,preun):	/sbin/chkconfig
Requires(postun):	/usr/sbin/groupdel
Requires(pre):	/usr/bin/getgid
Requires(pre):	/usr/sbin/groupadd
Requires:	rc-scripts >= 0.4.0.10
Requires:	dnsmasq
Requires:	rsync
Requires:	squashfs
Requires:	iproute2
Requires:	uname(release) >= 4.1
Provides:	group(lxd)
ExclusiveArch:	%{ix86} %{x8664} %{arm}
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%define		_enable_debug_packages 0
%define		gobuild(o:) go build -ldflags "${LDFLAGS:-} -B 0x$(head -c20 /dev/urandom|od -An -tx1|tr -d ' \\n')" -a -v -x %{?**};
%define		gopath		%{_libdir}/golang
%define		import_path	github.com/lxc/lxd
%define		_libexecdir	%{_prefix}/lib

%description
LXD is a container "hypervisor" and a new user experience for LXC.

Specifically, it is made of three components:
- A system-wide daemon (lxd)
- A command line client (lxc)
- An OpenStack Nova plugin (nova-compute-lxd)

The daemon exports a REST API both locally and if enabled, over the
network.

The command line tool is designed to be a very simple, yet very
powerful tool to manage all your containers. It can handle connect to
multiple container hosts and easily give you an overview of all the
containers on your network, let you create some more where you want
them and even move them around while they are running.

The OpenStack plugin then allows you to use your lxd hosts as compute
nodes, running workloads on containers rather than virtual machines.

%prep
%setup -q

%build
export GOPATH=$(pwd)/dist
cd $GOPATH/src/%{import_path}

%gobuild -o dist/bin/lxd ./lxd
%gobuild -o dist/bin/lxc ./lxc

%install
rm -rf $RPM_BUILD_ROOT
install -d $RPM_BUILD_ROOT{%{_bindir},%{_sbindir},%{_mandir}/man1,/etc/{rc.d/init.d,sysconfig},%{systemdunitdir}} \
	$RPM_BUILD_ROOT%{_libexecdir} \
	$RPM_BUILD_ROOT/var/lib/%{name}/{containers,devices,devlxd,images,security,shmounts,snapshots} \
	$RPM_BUILD_ROOT/var/log/%{name}

# lxd refuses to start containter without this directory
install -d $RPM_BUILD_ROOT%{_libdir}/%{name}/rootfs

install -p dist/bin/lxd $RPM_BUILD_ROOT%{_sbindir}
install -p dist/bin/lxc $RPM_BUILD_ROOT%{_bindir}

cp -p %{SOURCE1} $RPM_BUILD_ROOT%{systemdunitdir}
install -p %{SOURCE2} $RPM_BUILD_ROOT/etc/rc.d/init.d/%{name}
install -p %{SOURCE3} $RPM_BUILD_ROOT/etc/rc.d/init.d/%{name}br
cp -p %{SOURCE4} $RPM_BUILD_ROOT/etc/sysconfig/%{name}

install -p %{SOURCE5} $RPM_BUILD_ROOT%{_libexecdir}/lxd-wrapper

%pre
%groupadd -g 273 %{name}

%post
/sbin/chkconfig --add %{name}br
/sbin/chkconfig --add %{name}
%service -n %{name} restart
%systemd_post %{name}.service

%preun
if [ "$1" = "0" ]; then
	%service -q %{name} stop
	%service -q %{name}br stop
	/sbin/chkconfig --del %{name}
	/sbin/chkconfig --del %{name}br
fi
%systemd_preun %{name}.service

%postun
if [ "$1" = "0" ]; then
	%groupremove %{name}
fi
%systemd_reload

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(644,root,root,755)
%doc README.md CONTRIBUTING.md AUTHORS doc/*
%config(noreplace) %verify(not md5 mtime size) /etc/sysconfig/%{name}
%attr(754,root,root) /etc/rc.d/init.d/%{name}
%attr(754,root,root) /etc/rc.d/init.d/%{name}br
%attr(755,root,root) %{_bindir}/lxc
%attr(755,root,root) %{_sbindir}/lxd
%{systemdunitdir}/%{name}.service
%dir %attr(750,root,root) %{_libdir}/%{name}
%dir %attr(750,root,root) %{_libdir}/%{name}/rootfs
%attr(750,root,root) %{_libexecdir}/%{name}-wrapper
%dir %attr(750,root,logs) /var/log/%{name}
%dir %attr(711,root,root) /var/lib/%{name}
%dir %attr(711,root,root) /var/lib/%{name}/containers
%dir %attr(700,root,root) /var/lib/%{name}/devices
%dir %attr(700,root,root) /var/lib/%{name}/devlxd
%dir %attr(700,root,root) /var/lib/%{name}/images
%dir %attr(700,root,root) /var/lib/%{name}/security
%dir %attr(711,root,root) /var/lib/%{name}/shmounts
%dir %attr(700,root,root) /var/lib/%{name}/snapshots
%changelog
* Tue Dec 20 2016 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/lxd.git;a=log;h=master

* Tue Dec 20 2016 Mateusz Korniak <matkor@pld-linux.org> bda6ba7
- up to 2.6.2; rel 1

* Thu Nov 24 2016 Mateusz Korniak <matkor@pld-linux.org> 8cf49c5
- lxd.service switch to Type=simple, ExecStop= added.

* Thu Nov 24 2016 Mateusz Korniak <matkor@pld-linux.org> 7cafd61
- up to 2.6;
R: dnsmasq as refuses to start without

* Wed Nov 16 2016 Mateusz Korniak <matkor@pld-linux.org> cb1a22f
- up to 2.5; rel 1

* Fri Sep 23 2016 mis <mis@pld-linux.org> 10d7233
- up to 2.2; rel 1

* Tue Aug 23 2016 Elan Ruusamäe <glen@delfi.ee> 543b45a
- wrong usage means errors

* Tue Aug 23 2016 Elan Ruusamäe <glen@delfi.ee> 703703b
- quote args

* Mon Aug 22 2016 mis <mis@pld-linux.org> 3d07792
- too much spaces

* Mon Aug 22 2016 mis <mis@pld-linux.org> f64fdf3
- use 'ip link show up'

* Mon Aug 22 2016 mis <mis@pld-linux.org> 6a7ae82
- need 711 on some /var/lib/lxd dirs (see https://github.com/lxc/lxc/issues/688)
- missing _libexec

* Mon Aug 22 2016 mis <mis@pld-linux.org> 8f78a48
- missing lxd wrapper script

* Mon Aug 22 2016 mis <mis@pld-linux.org> c04fdf4
- run lxd via lxd-wrapper script as --redirfds does not help here (because of golang?); rel 0.3

* Mon Aug 22 2016 mis <mis@pld-linux.org> 485326f
- fixed is_bridge_up()

* Mon Aug 22 2016 mis <mis@pld-linux.org> 2181964
- check if bridge is up and nothing more

* Mon Aug 22 2016 mis <mis@pld-linux.org> 4ecaeaa
- check bridge status before start

* Mon Aug 22 2016 mis <mis@pld-linux.org> 92a9efa
- fixed rootfs %dir

* Mon Aug 22 2016 mis <mis@pld-linux.org> 78a93e6
- lxd bridge service  registration

* Mon Aug 22 2016 mis <mis@pld-linux.org> 5e23fd3
- ldx bridge must be started before lxd

* Mon Aug 22 2016 mis <mis@pld-linux.org> 4d00c17
- lxc stderr to /dev/null

* Sun Aug 21 2016 mis <mistoo@gmail.com> e06ffcb
- fix: use BRIDGE_DEV env

